@@ -10,9 +10,9 @@
 ExampleFX =function(JSON = FALSE)
 {
   requireNamespace("Trading")
-tr1 = Trading::FXSwap(external_id = "ext_1",Notional=10000,MtM=30,ccyPair="EUR/USD",Si=0,Ei=10,BuySell='Buy')
-tr2 = Trading::FXSwap(external_id = "ext_2",Notional=20000,MtM=-20,ccyPair="EUR/USD",Si=0,Ei=4,BuySell='Sell')
-tr3 = Trading::FXSwap(external_id = "ext_3",Notional=5000,MtM=50,ccyPair="GBP/USD",Si=1,Ei=11,BuySell='Sell')
+tr1 = Trading::FxForward(external_id = "ext_1",Notional=10000,MtM=30,ccyPair="EUR/USD",Si=0,Ei=10,BuySell='Buy')
+tr2 = Trading::FxForward(external_id = "ext_2",Notional=20000,MtM=-20,ccyPair="EUR/USD",Si=0,Ei=4,BuySell='Sell')
+tr3 = Trading::FxForward(external_id = "ext_3",Notional=5000,MtM=50,ccyPair="GBP/USD",Si=1,Ei=11,BuySell='Sell')
 
 trades= list(tr1,tr2,tr3)
 
@@ -27,8 +27,6 @@ if(JSON==TRUE)
   return(jsonlite::toJSON(as.list(tree[[1]])))
 }
 else
-{
-  return(tree[[1]])
-}
+{  return(tree[[1]])}
 
 }
\ No newline at end of file
